pitchtools.list_inversion_equivalent_chromatic_interval_classes_pairwise_between_pitch_carriers
===============================================================================================

.. autofunction:: abjad.tools.pitchtools.list_inversion_equivalent_chromatic_interval_classes_pairwise_between_pitch_carriers.list_inversion_equivalent_chromatic_interval_classes_pairwise_between_pitch_carriers
